Crate swc_export_order

This is an swc plugin which injects a constant named __namedExportsOrder defined as an array of strings representing an ordered list of named exports.

Structs

PluginDiagnosticsEmitter
An emitter for the Diagnostic in plugin’s context by borrowing host’s environment context.

Functions

__get_transform_plugin_core_pkg_diag
__transform_plugin_process_impl
extract_bindings
Iterate over all of the bindings in a pattern recursively, to capture every bound name in an arbitrarily deep destructuring assignment.
process_transform
Entry point for the plugin.