This is an swc plugin which injects a constant named __namedExportsOrder
defined as an array of strings representing an ordered list of named
exports.
Structs
- Plugin
Diagnostics Emitter - An emitter for the Diagnostic in plugin’s context by borrowing host’s environment context.
Functions
- __
get_ transform_ plugin_ core_ pkg_ diag - __
transform_ plugin_ process_ impl - extract_
bindings - Iterate over all of the bindings in a pattern recursively, to capture every bound name in an arbitrarily deep destructuring assignment.
- process_
transform - Entry point for the plugin.